@@ -47,6 +47,8 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
     {"Left",      GDK_KEY_Left},
     {"PageDown",  GDK_KEY_Page_Down},
     {"PageUp",    GDK_KEY_Page_Up},
+    {"Home",      GDK_KEY_Home},
+    {"End",       GDK_KEY_End},
     {"Return",    GDK_KEY_Return},
     {"Right",     GDK_KEY_Right},
     {"Space",     GDK_KEY_space},
@@ -103,12 +105,11 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
 
   size_t number_of_arguments = girara_list_size(argument_list);
 
-  if (number_of_arguments < ((unmap == true) ? 1 : 2)) {
-    if (unmap == true) {
-      girara_notify(session, GIRARA_WARNING, _("Usage: unmap <binding>"));
-    } else {
-      girara_notify(session, GIRARA_WARNING, _("Usage: map <binding> <function>"));
-    }
+  unsigned int limit = (unmap == true) ? 1 : 2;
+  if (number_of_arguments < limit) {
+    girara_warning("Invalid number of arguments passed: %zu instead of at least %u", number_of_arguments, limit);
+    girara_notify(session, GIRARA_ERROR,
+        _("Invalid number of arguments passed: %zu instead of at least %u"), number_of_arguments, limit);
     return false;
   }
 
@@ -149,14 +150,6 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
     g_free(tmp_inner);
   }
 
-  unsigned int limit = (unmap == true) ? 1 : 2;
-  if (number_of_arguments < limit) {
-    girara_warning("Invalid number of arguments passed: %zu instead of at least %u", number_of_arguments, limit);
-    girara_notify(session, GIRARA_ERROR,
-        _("Invalid number of arguments passed: %zu instead of at least %u"), number_of_arguments, limit);
-    return false;
-  }
-
   if (is_mode == true) {
     tmp = girara_list_nth(argument_list, ++current_command);
     tmp_length = strlen(tmp);
@@ -168,12 +161,13 @@ girara_cmd_map_unmap(girara_session_t* session, girara_list_t* argument_list,
     tmp_length = strlen(tmp);
 
     /* Multi key shortcut */
-    if (strchr(tmp, '-') != NULL && tmp_length > 2) {
+    if (strchr(tmp, '-') != NULL && tmp[1] == '-' && tmp_length > 2) {
       switch (tmp[0]) {
         case 'S':
           shortcut_mask = GDK_SHIFT_MASK;
           break;
         case 'A':
+        case 'M':
           shortcut_mask = GDK_MOD1_MASK;
           break;
         case 'C':
@@ -509,7 +503,7 @@ girara_cmd_set(girara_session_t* session, girara_list_t* argument_list)
         break;
       case FLOAT:
       {
-        float f = strtof(value, NULL);
+        float f = g_ascii_strtod(value, NULL);
         girara_setting_set_value(session, setting, &f);
         break;
       }
@@ -625,33 +619,9 @@ girara_command_free(girara_command_t* command)
 bool
 girara_cmd_exec(girara_session_t* session, girara_list_t* argument_list)
 {
-  char* cmd = NULL;
-  girara_setting_get(session, "exec-command", &cmd);
-  if (cmd == NULL || strlen(cmd) == 0) {
-    girara_warning("exec-command is invalid.");
-    girara_notify(session, GIRARA_ERROR, _("exec-command is invalid."));
-    g_free(cmd);
-    return false;
+  if (session == NULL || argument_list == NULL) {
+    return true;
   }
 
-  GString* command = g_string_new(cmd);
-  g_free(cmd);
-
-  GIRARA_LIST_FOREACH(argument_list, char*, iter, value)
-    g_string_append_c(command, ' ');
-    char* tmp = g_shell_quote(value);
-    g_string_append(command, tmp);
-    g_free(tmp);
-  GIRARA_LIST_FOREACH_END(argument_list, char*, iter, value);
-
-  GError* error = NULL;
-  gboolean ret = g_spawn_command_line_async(command->str, &error);
-  if (error != NULL) {
-    girara_warning("Failed to execute command: %s", error->message);
-    girara_notify(session, GIRARA_ERROR, _("Failed to execute command: %s"), error->message);
-    g_error_free(error);
-  }
-
-  g_string_free(command, TRUE);
-  return ret;
+  return girara_exec_with_argument_list(session, argument_list);
 }
