@@ -133,6 +133,32 @@ bool girara_sc_tab_close(girara_session_t* session, girara_argument_t* argument,
 bool girara_sc_tab_navigate(girara_session_t* session, girara_argument_t*
     argument, girara_event_t* event, unsigned int t);
 
+/**
+ * Navigate to the next tab
+ *
+ * @param session The used girara session
+ * @param argument The used argument
+ * @param event Girara event
+ * @param t Number of executions
+ * @return true if no error occured otherwise false
+ */
+bool girara_sc_tab_navigate_next(girara_session_t* session,
+                                 girara_argument_t* argument,
+                                 girara_event_t* event, unsigned int t);
+
+/**
+ * Navigate to the previous tab
+ *
+ * @param session The used girara session
+ * @param argument The used argument
+ * @param event Girara event
+ * @param t Number of executions
+ * @return true if no error occured otherwise false
+ */
+bool girara_sc_tab_navigate_prev(girara_session_t* session,
+                                 girara_argument_t* argument,
+                                 girara_event_t* event, unsigned int t);
+
 /**
  * Toggles the visibility of the inputbar
  *
